x.cod <-
structure(list(N = structure(list(Sex = c("Unisex", "Unisex", 
"Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
"Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
"Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
"Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
"Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
"Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
"Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
"Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
"Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
"Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
"Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
"Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
"Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
"Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
"Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
"Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
"Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
"Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
"Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
"Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
"Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
"Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
"Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
"Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
"Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
"Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
"Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
"Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
"Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
"Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
"Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
"Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
"Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
"Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
"Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
"Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
"Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
"Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
"Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
"Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
"Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
"Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
"Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
"Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
"Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
"Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
"Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
"Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
"Unisex", "Unisex"), Year = c(1971L, 1971L, 1971L, 1971L, 1971L, 
1971L, 1971L, 1971L, 1971L, 1971L, 1972L, 1972L, 1972L, 1972L, 
1972L, 1972L, 1972L, 1972L, 1972L, 1972L, 1973L, 1973L, 1973L, 
1973L, 1973L, 1973L, 1973L, 1973L, 1973L, 1973L, 1974L, 1974L, 
1974L, 1974L, 1974L, 1974L, 1974L, 1974L, 1974L, 1974L, 1975L, 
1975L, 1975L, 1975L, 1975L, 1975L, 1975L, 1975L, 1975L, 1975L, 
1976L, 1976L, 1976L, 1976L, 1976L, 1976L, 1976L, 1976L, 1976L, 
1976L, 1977L, 1977L, 1977L, 1977L, 1977L, 1977L, 1977L, 1977L, 
1977L, 1977L, 1978L, 1978L, 1978L, 1978L, 1978L, 1978L, 1978L, 
1978L, 1978L, 1978L, 1979L, 1979L, 1979L, 1979L, 1979L, 1979L, 
1979L, 1979L, 1979L, 1979L, 1980L, 1980L, 1980L, 1980L, 1980L, 
1980L, 1980L, 1980L, 1980L, 1980L, 1981L, 1981L, 1981L, 1981L, 
1981L, 1981L, 1981L, 1981L, 1981L, 1981L, 1982L, 1982L, 1982L, 
1982L, 1982L, 1982L, 1982L, 1982L, 1982L, 1982L, 1983L, 1983L, 
1983L, 1983L, 1983L, 1983L, 1983L, 1983L, 1983L, 1983L, 1984L, 
1984L, 1984L, 1984L, 1984L, 1984L, 1984L, 1984L, 1984L, 1984L, 
1985L, 1985L, 1985L, 1985L, 1985L, 1985L, 1985L, 1985L, 1985L, 
1985L, 1986L, 1986L, 1986L, 1986L, 1986L, 1986L, 1986L, 1986L, 
1986L, 1986L, 1987L, 1987L, 1987L, 1987L, 1987L, 1987L, 1987L, 
1987L, 1987L, 1987L, 1988L, 1988L, 1988L, 1988L, 1988L, 1988L, 
1988L, 1988L, 1988L, 1988L, 1989L, 1989L, 1989L, 1989L, 1989L, 
1989L, 1989L, 1989L, 1989L, 1989L, 1990L, 1990L, 1990L, 1990L, 
1990L, 1990L, 1990L, 1990L, 1990L, 1990L, 1991L, 1991L, 1991L, 
1991L, 1991L, 1991L, 1991L, 1991L, 1991L, 1991L, 1992L, 1992L, 
1992L, 1992L, 1992L, 1992L, 1992L, 1992L, 1992L, 1992L, 1993L, 
1993L, 1993L, 1993L, 1993L, 1993L, 1993L, 1993L, 1993L, 1993L, 
1994L, 1994L, 1994L, 1994L, 1994L, 1994L, 1994L, 1994L, 1994L, 
1994L, 1995L, 1995L, 1995L, 1995L, 1995L, 1995L, 1995L, 1995L, 
1995L, 1995L, 1996L, 1996L, 1996L, 1996L, 1996L, 1996L, 1996L, 
1996L, 1996L, 1996L, 1997L, 1997L, 1997L, 1997L, 1997L, 1997L, 
1997L, 1997L, 1997L, 1997L, 1998L, 1998L, 1998L, 1998L, 1998L, 
1998L, 1998L, 1998L, 1998L, 1998L, 1999L, 1999L, 1999L, 1999L, 
1999L, 1999L, 1999L, 1999L, 1999L, 1999L, 2000L, 2000L, 2000L, 
2000L, 2000L, 2000L, 2000L, 2000L, 2000L, 2000L, 2001L, 2001L, 
2001L, 2001L, 2001L, 2001L, 2001L, 2001L, 2001L, 2001L, 2002L, 
2002L, 2002L, 2002L, 2002L, 2002L, 2002L, 2002L, 2002L, 2002L, 
2003L, 2003L, 2003L, 2003L, 2003L, 2003L, 2003L, 2003L, 2003L, 
2003L, 2004L, 2004L, 2004L, 2004L, 2004L, 2004L, 2004L, 2004L, 
2004L, 2004L), Age = c(1L, 2L, 3L, 4L, 5L, 6L, 7L, 8L, 9L, 10L, 
1L, 2L, 3L, 4L, 5L, 6L, 7L, 8L, 9L, 10L, 1L, 2L, 3L, 4L, 5L, 
6L, 7L, 8L, 9L, 10L, 1L, 2L, 3L, 4L, 5L, 6L, 7L, 8L, 9L, 10L, 
1L, 2L, 3L, 4L, 5L, 6L, 7L, 8L, 9L, 10L, 1L, 2L, 3L, 4L, 5L, 
6L, 7L, 8L, 9L, 10L, 1L, 2L, 3L, 4L, 5L, 6L, 7L, 8L, 9L, 10L, 
1L, 2L, 3L, 4L, 5L, 6L, 7L, 8L, 9L, 10L, 1L, 2L, 3L, 4L, 5L, 
6L, 7L, 8L, 9L, 10L, 1L, 2L, 3L, 4L, 5L, 6L, 7L, 8L, 9L, 10L, 
1L, 2L, 3L, 4L, 5L, 6L, 7L, 8L, 9L, 10L, 1L, 2L, 3L, 4L, 5L, 
6L, 7L, 8L, 9L, 10L, 1L, 2L, 3L, 4L, 5L, 6L, 7L, 8L, 9L, 10L, 
1L, 2L, 3L, 4L, 5L, 6L, 7L, 8L, 9L, 10L, 1L, 2L, 3L, 4L, 5L, 
6L, 7L, 8L, 9L, 10L, 1L, 2L, 3L, 4L, 5L, 6L, 7L, 8L, 9L, 10L, 
1L, 2L, 3L, 4L, 5L, 6L, 7L, 8L, 9L, 10L, 1L, 2L, 3L, 4L, 5L, 
6L, 7L, 8L, 9L, 10L, 1L, 2L, 3L, 4L, 5L, 6L, 7L, 8L, 9L, 10L, 
1L, 2L, 3L, 4L, 5L, 6L, 7L, 8L, 9L, 10L, 1L, 2L, 3L, 4L, 5L, 
6L, 7L, 8L, 9L, 10L, 1L, 2L, 3L, 4L, 5L, 6L, 7L, 8L, 9L, 10L, 
1L, 2L, 3L, 4L, 5L, 6L, 7L, 8L, 9L, 10L, 1L, 2L, 3L, 4L, 5L, 
6L, 7L, 8L, 9L, 10L, 1L, 2L, 3L, 4L, 5L, 6L, 7L, 8L, 9L, 10L, 
1L, 2L, 3L, 4L, 5L, 6L, 7L, 8L, 9L, 10L, 1L, 2L, 3L, 4L, 5L, 
6L, 7L, 8L, 9L, 10L, 1L, 2L, 3L, 4L, 5L, 6L, 7L, 8L, 9L, 10L, 
1L, 2L, 3L, 4L, 5L, 6L, 7L, 8L, 9L, 10L, 1L, 2L, 3L, 4L, 5L, 
6L, 7L, 8L, 9L, 10L, 1L, 2L, 3L, 4L, 5L, 6L, 7L, 8L, 9L, 10L, 
1L, 2L, 3L, 4L, 5L, 6L, 7L, 8L, 9L, 10L, 1L, 2L, 3L, 4L, 5L, 
6L, 7L, 8L, 9L, 10L, 1L, 2L, 3L, 4L, 5L, 6L, 7L, 8L, 9L, 10L), 
    N = c(472457, 172835, 162647, 135592, 112548, 51297.2, 41974.6, 
    27548.5, 12444.9, 17569.8, 262806, 386744, 140900, 127383, 
    89481, 57003.5, 25276.4, 20682.7, 13574.4, 14789.6, 425777, 
    215126, 315234, 110164, 83310, 44279.4, 27395.7, 12147.8, 
    9940.07, 13631.7, 628953, 348515, 175177, 243911, 68056.4, 
    35289.4, 17986.6, 11128.3, 4934.5, 9575.04, 207659, 514819, 
    283750, 135313, 149252, 28043.6, 13910.1, 7089.79, 4386.47, 
    5719.29, 360187, 169979, 419340, 220242, 85064.5, 66414.1, 
    12017.7, 5960.96, 3038.23, 4330.7, 401021, 294838, 138537, 
    327544, 143288, 41522.2, 31452.5, 5691.34, 2823, 3489.8, 
    229905, 328279, 240556, 109431, 225994, 81035.3, 23020, 17437.3, 
    3155.29, 3499.83, 234366, 188208, 268022, 191374, 78262.4, 
    139010, 49119.3, 13953.5, 10569.6, 4033.99, 186469, 191858, 
    153635, 212839, 135635, 47150.4, 82426.3, 29125.4, 8273.75, 
    8659.21, 328677, 152646, 156559, 121550, 148043, 78200.3, 
    26682.1, 46644.4, 16481.8, 9582.26, 213028, 269049, 124446, 
    122667, 80396.6, 75417.8, 38773.5, 13229.6, 23127.4, 12923.2, 
    185820, 174379, 219301, 97299, 80223.1, 39780.6, 36242.2, 
    18632.7, 6357.52, 17324.3, 530062, 152109, 142176, 171976, 
    64652.2, 41347.5, 19972.3, 18195.8, 9354.78, 11889.8, 510445, 
    433905, 124050, 111789, 115866, 34500.1, 21545.5, 10407.2, 
    9481.53, 11070.2, 277039, 417840, 353751, 97211.5, 74005.2, 
    59157.3, 17146.8, 10708.3, 5172.47, 10214.4, 117558, 226770, 
    340337, 274491, 61009.1, 32776.5, 25222.2, 7310.69, 4565.57, 
    6560.36, 192850, 96225.4, 184656, 263295, 169428, 25779.4, 
    13278.4, 10218, 2961.71, 4507.36, 146381, 157860, 78414.3, 
    144007, 169858, 80880.4, 11919.2, 6139.31, 4724.34, 3453.36, 
    260156, 119826, 128727, 61586.9, 96463.6, 89343.5, 41500.5, 
    6115.85, 3150.14, 4196.07, 232307, 212955, 97654.7, 100481, 
    39924.8, 46644.9, 41884.4, 19455.5, 2867.13, 3443.94, 103293, 
    190152, 173406, 75546.5, 62012.4, 16863.4, 18888.4, 16960.7, 
    7878.34, 2555.62, 242279, 84547.9, 154780, 133613, 45581.6, 
    24510, 6350.95, 7113.6, 6387.62, 3929.58, 301904, 198312, 
    68823.3, 119317, 80830.9, 18159.7, 9311.52, 2412.77, 2702.51, 
    3919.59, 112824, 247134, 161698, 54003.2, 79529.8, 41990.2, 
    9194.56, 4714.58, 1221.63, 3352.89, 226670, 92358.2, 201626, 
    127672, 37178.2, 44739.6, 23148.4, 5068.78, 2599.06, 2521.85, 
    66566.4, 185554, 75361.1, 159420, 88524.1, 21274.9, 25116.6, 
    12995.4, 2845.6, 2874.86, 265870, 54492.4, 151433, 59697.5, 
    111593, 51809.5, 12232.8, 14441.7, 7472.2, 3289.2, 255701, 
    217641, 44450.3, 119350, 40716.8, 61373.9, 27881.6, 6583.15, 
    7771.91, 5791.32, 263285, 209311, 177419, 34796.1, 78562.4, 
    20488.1, 30030.4, 13642.5, 3221.15, 6636.54, 343564, 215516, 
    170582, 138482, 22551.7, 37964.7, 9598.29, 14068.7, 6391.29, 
    4618.17, 87727.6, 281228, 175601, 132845, 88662.9, 10549.2, 
    17172.8, 4341.67, 6363.81, 4980.01, 310215, 71812.9, 229330, 
    137941, 89063.6, 46737, 5425.48, 8832.03, 2232.93, 5834.17, 
    378867, 253943, 58587.1, 181008, 94794.7, 49886.8, 25646.8, 
    2977.22, 4846.56, 4426.82)), .Names = c("Sex", "Year", "Age", 
"N"), row.names = c(NA, -340L), class = "data.frame"), B = structure(list(
    Year = 1971:2004, VB = c(1140000, 964964, 761019, 722716, 
    778435, 825133, 1050000, 1270000, 1330000, 1410000, 1190000, 
    940285, 775779, 780698, 827749, 769197, 776460, 868580, 953567, 
    784715, 610520, 495860, 470127, 468598, 518647, 577960, 682386, 
    708012, 646309, 550857, 525343, 561627, 636831, 734505), 
    SB = c(1370000, 1170000, 894552, 999547, 966587, 1060000, 
    1480000, 1500000, 1630000, 1750000, 1410000, 1130000, 918667, 
    1e+06, 1020000, 900452, 1090000, 1190000, 1200000, 912646, 
    762816, 598591, 630708, 642020, 613469, 737990, 906160, 828555, 
    817466, 623002, 700825, 737061, 808611, 982954), Y = c(453052, 
    398528, 383446, 374770, 370991, 347849, 340050, 330390, 368064, 
    434344, 468659, 388387, 300056, 283822, 325267, 368633, 392257, 
    378076, 355954, 335390, 308560, 267767, 251979, 178809, 169424, 
    181658, 203153, 242632, 260052, 235654, 235098, 208830, 210000, 
    NA), R = c(262806, 425777, 628953, 207659, 360187, 401021, 
    229905, 234366, 186469, 328677, 213028, 185820, 530062, 510445, 
    277039, 117558, 192850, 146381, 260156, 232307, 103293, 242279, 
    301904, 112824, 226670, 66566.4, 265870, 255701, 263285, 
    343564, 87727.6, 310215, 378867, NA)), .Names = c("Year", 
"VB", "SB", "Y", "R"), row.names = c(NA, -34L), class = "data.frame"), 
    Sel = structure(list(Series = c("Gear 1", "Gear 1", "Gear 1", 
    "Gear 1", "Gear 1", "Gear 1", "Gear 1", "Gear 1", "Gear 1", 
    "Gear 1", "Survey 1", "Survey 1", "Survey 1", "Survey 1", 
    "Survey 1", "Survey 1", "Survey 1", "Survey 1", "Survey 1", 
    "Survey 1", "Maturity", "Maturity", "Maturity", "Maturity", 
    "Maturity", "Maturity", "Maturity", "Maturity", "Maturity", 
    "Maturity"), Sex = c("Unisex", "Unisex", "Unisex", "Unisex", 
    "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
    "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
    "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
    "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
    "Unisex", "Unisex"), Age = c(1L, 2L, 3L, 4L, 5L, 6L, 7L, 
    8L, 9L, 10L, 1L, 2L, 3L, 4L, 5L, 6L, 7L, 8L, 9L, 10L, 1L, 
    2L, 3L, 4L, 5L, 6L, 7L, 8L, 9L, 10L), P = c(0.000465918, 
    0.0107437, 0.109044, 0.487138, 0.957858, 1, 0.999999, 0.999998, 
    0.999996, 0.999993, 0.093353, 0.30199, 0.656636, 0.959678, 
    1, 0.999999, 0.999998, 0.999996, 0.999994, 0.999991, 0, 0, 
    0, 1, 1, 1, 1, 1, 1, 1)), .Names = c("Series", "Sex", "Age", 
    "P"), row.names = c(NA, -30L), class = "data.frame"), Dev = structure(list(
        Initial = structure(c(-0.276004, -0.133551, -0.08248, 
        0.0879693, -0.161992, 0.19093, 0.323306, 0.082165), .Names = c("2", 
        "3", "4", "5", "6", "7", "8", "9")), Annual = structure(c(0.904468, 
        0.0370796, 0.544025, 0.98496, -0.145333, 0.411873, 0.501718, 
        -0.107777, -0.0903785, -0.329944, 0.228531, -0.176938, 
        -0.278815, 0.808412, 0.753572, 0.138847, -0.693534, -0.235523, 
        -0.526445, 0.0482014, -0.0151754, -0.786165, 0.129073, 
        0.334609, -0.654477, 0.0556041, -1.21763, 0.121238, 0.101377, 
        0.133603, 0.467231, -0.928844, 0.321739), .Names = c("1971", 
        "1972", "1973", "1974", "1975", "1976", "1977", "1978", 
        "1979", "1980", "1981", "1982", "1983", "1984", "1985", 
        "1986", "1987", "1988", "1989", "1990", "1991", "1992", 
        "1993", "1994", "1995", "1996", "1997", "1998", "1999", 
        "2000", "2001", "2002", "2003"))), .Names = c("Initial", 
    "Annual")), Survey = structure(list(Series = c(1L, 1L, 1L, 
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 
    1L), Year = 1971:2004, Obs = c(NA, NA, NA, NA, NA, NA, NA, 
    NA, NA, NA, NA, NA, NA, NA, 548.4, 402.2, 493.1, 561.3, 522, 
    307, 291.9, 203.8, 220.3, 177.8, 224.2, 325.9, 347, 422.6, 
    282.2, 251.9, 236.1, 310, 344.5, NA), CV = c(NA, NA, NA, 
    NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, 0.2, 0.2, 0.2, 
    0.2, 0.2, 0.2, 0.2, 0.2, 0.2, 0.2, 0.2, 0.2, 0.2, 0.2, 0.2, 
    0.2, 0.2, 0.2, 0.2, NA), Fit = c(509.758, 436.334, 375.37, 
    376.073, 395.967, 482.794, 535.93, 578.928, 636.372, 638.789, 
    519.153, 410.725, 364.678, 378.4, 384.105, 419.75, 464.846, 
    459.498, 424.87, 346.746, 285.949, 252.182, 259.693, 237.64, 
    256.392, 313.859, 329.732, 322.584, 288.12, 263.397, 292.159, 
    298.522, 342.267, 348.371)), .Names = c("Series", "Year", 
    "Obs", "CV", "Fit"), row.names = c(NA, -34L), class = "data.frame"), 
    CAc = structure(list(Series = c(1L, 1L, 1L, 1L, 1L, 1L, 1L, 
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L), Year = c(1971L, 
    1971L, 1971L, 1971L, 1971L, 1971L, 1971L, 1971L, 1971L, 1971L, 
    1972L, 1972L, 1972L, 1972L, 1972L, 1972L, 1972L, 1972L, 1972L, 
    1972L, 1973L, 1973L, 1973L, 1973L, 1973L, 1973L, 1973L, 1973L, 
    1973L, 1973L, 1974L, 1974L, 1974L, 1974L, 1974L, 1974L, 1974L, 
    1974L, 1974L, 1974L, 1975L, 1975L, 1975L, 1975L, 1975L, 1975L, 
    1975L, 1975L, 1975L, 1975L, 1976L, 1976L, 1976L, 1976L, 1976L, 
    1976L, 1976L, 1976L, 1976L, 1976L, 1977L, 1977L, 1977L, 1977L, 
    1977L, 1977L, 1977L, 1977L, 1977L, 1977L, 1978L, 1978L, 1978L, 
    1978L, 1978L, 1978L, 1978L, 1978L, 1978L, 1978L, 1979L, 1979L, 
    1979L, 1979L, 1979L, 1979L, 1979L, 1979L, 1979L, 1979L, 1980L, 
    1980L, 1980L, 1980L, 1980L, 1980L, 1980L, 1980L, 1980L, 1980L, 
    1981L, 1981L, 1981L, 1981L, 1981L, 1981L, 1981L, 1981L, 1981L, 
    1981L, 1982L, 1982L, 1982L, 1982L, 1982L, 1982L, 1982L, 1982L, 
    1982L, 1982L, 1983L, 1983L, 1983L, 1983L, 1983L, 1983L, 1983L, 
    1983L, 1983L, 1983L, 1984L, 1984L, 1984L, 1984L, 1984L, 1984L, 
    1984L, 1984L, 1984L, 1984L, 1985L, 1985L, 1985L, 1985L, 1985L, 
    1985L, 1985L, 1985L, 1985L, 1985L, 1986L, 1986L, 1986L, 1986L, 
    1986L, 1986L, 1986L, 1986L, 1986L, 1986L, 1987L, 1987L, 1987L, 
    1987L, 1987L, 1987L, 1987L, 1987L, 1987L, 1987L, 1988L, 1988L, 
    1988L, 1988L, 1988L, 1988L, 1988L, 1988L, 1988L, 1988L, 1989L, 
    1989L, 1989L, 1989L, 1989L, 1989L, 1989L, 1989L, 1989L, 1989L, 
    1990L, 1990L, 1990L, 1990L, 1990L, 1990L, 1990L, 1990L, 1990L, 
    1990L, 1991L, 1991L, 1991L, 1991L, 1991L, 1991L, 1991L, 1991L, 
    1991L, 1991L, 1992L, 1992L, 1992L, 1992L, 1992L, 1992L, 1992L, 
    1992L, 1992L, 1992L, 1993L, 1993L, 1993L, 1993L, 1993L, 1993L, 
    1993L, 1993L, 1993L, 1993L, 1994L, 1994L, 1994L, 1994L, 1994L, 
    1994L, 1994L, 1994L, 1994L, 1994L, 1995L, 1995L, 1995L, 1995L, 
    1995L, 1995L, 1995L, 1995L, 1995L, 1995L, 1996L, 1996L, 1996L, 
    1996L, 1996L, 1996L, 1996L, 1996L, 1996L, 1996L, 1997L, 1997L, 
    1997L, 1997L, 1997L, 1997L, 1997L, 1997L, 1997L, 1997L, 1998L, 
    1998L, 1998L, 1998L, 1998L, 1998L, 1998L, 1998L, 1998L, 1998L, 
    1999L, 1999L, 1999L, 1999L, 1999L, 1999L, 1999L, 1999L, 1999L, 
    1999L, 2000L, 2000L, 2000L, 2000L, 2000L, 2000L, 2000L, 2000L, 
    2000L, 2000L, 2001L, 2001L, 2001L, 2001L, 2001L, 2001L, 2001L, 
    2001L, 2001L, 2001L, 2002L, 2002L, 2002L, 2002L, 2002L, 2002L, 
    2002L, 2002L, 2002L, 2002L), SS = c(50, 50, 50, 50, 50, 50, 
    50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 
    50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 
    50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 
    50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 
    50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 
    50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 
    50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 
    50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 
    50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 
    50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 
    50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 
    50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 
    50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 
    50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 
    50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 
    50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 
    50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 
    50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 
    50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 
    50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 
    50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50), 
        Sex = c("Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
        "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
        "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
        "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
        "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
        "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
        "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
        "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
        "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
        "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
        "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
        "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
        "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
        "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
        "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
        "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
        "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
        "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
        "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
        "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
        "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
        "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
        "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
        "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
        "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
        "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
        "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
        "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
        "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
        "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
        "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
        "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
        "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
        "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
        "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
        "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
        "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
        "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
        "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
        "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
        "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
        "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
        "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
        "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
        "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
        "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
        "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
        "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
        "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
        "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
        "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
        "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
        "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
        "Unisex", "Unisex", "Unisex"), Age = c(1L, 2L, 3L, 4L, 
        5L, 6L, 7L, 8L, 9L, 10L, 1L, 2L, 3L, 4L, 5L, 6L, 7L, 
        8L, 9L, 10L, 1L, 2L, 3L, 4L, 5L, 6L, 7L, 8L, 9L, 10L, 
        1L, 2L, 3L, 4L, 5L, 6L, 7L, 8L, 9L, 10L, 1L, 2L, 3L, 
        4L, 5L, 6L, 7L, 8L, 9L, 10L, 1L, 2L, 3L, 4L, 5L, 6L, 
        7L, 8L, 9L, 10L, 1L, 2L, 3L, 4L, 5L, 6L, 7L, 8L, 9L, 
        10L, 1L, 2L, 3L, 4L, 5L, 6L, 7L, 8L, 9L, 10L, 1L, 2L, 
        3L, 4L, 5L, 6L, 7L, 8L, 9L, 10L, 1L, 2L, 3L, 4L, 5L, 
        6L, 7L, 8L, 9L, 10L, 1L, 2L, 3L, 4L, 5L, 6L, 7L, 8L, 
        9L, 10L, 1L, 2L, 3L, 4L, 5L, 6L, 7L, 8L, 9L, 10L, 1L, 
        2L, 3L, 4L, 5L, 6L, 7L, 8L, 9L, 10L, 1L, 2L, 3L, 4L, 
        5L, 6L, 7L, 8L, 9L, 10L, 1L, 2L, 3L, 4L, 5L, 6L, 7L, 
        8L, 9L, 10L, 1L, 2L, 3L, 4L, 5L, 6L, 7L, 8L, 9L, 10L, 
        1L, 2L, 3L, 4L, 5L, 6L, 7L, 8L, 9L, 10L, 1L, 2L, 3L, 
        4L, 5L, 6L, 7L, 8L, 9L, 10L, 1L, 2L, 3L, 4L, 5L, 6L, 
        7L, 8L, 9L, 10L, 1L, 2L, 3L, 4L, 5L, 6L, 7L, 8L, 9L, 
        10L, 1L, 2L, 3L, 4L, 5L, 6L, 7L, 8L, 9L, 10L, 1L, 2L, 
        3L, 4L, 5L, 6L, 7L, 8L, 9L, 10L, 1L, 2L, 3L, 4L, 5L, 
        6L, 7L, 8L, 9L, 10L, 1L, 2L, 3L, 4L, 5L, 6L, 7L, 8L, 
        9L, 10L, 1L, 2L, 3L, 4L, 5L, 6L, 7L, 8L, 9L, 10L, 1L, 
        2L, 3L, 4L, 5L, 6L, 7L, 8L, 9L, 10L, 1L, 2L, 3L, 4L, 
        5L, 6L, 7L, 8L, 9L, 10L, 1L, 2L, 3L, 4L, 5L, 6L, 7L, 
        8L, 9L, 10L, 1L, 2L, 3L, 4L, 5L, 6L, 7L, 8L, 9L, 10L, 
        1L, 2L, 3L, 4L, 5L, 6L, 7L, 8L, 9L, 10L, 1L, 2L, 3L, 
        4L, 5L, 6L, 7L, 8L, 9L, 10L, 1L, 2L, 3L, 4L, 5L, 6L, 
        7L, 8L, 9L, 10L), Obs = c(0, 0, 0.0845488, 0.232127, 
        0.29506, 0.136825, 0.112257, 0.0707206, 0.0388497, 0.0296115, 
        0, 0, 0.0695204, 0.229131, 0.239544, 0.177074, 0.0859766, 
        0.0758038, 0.0816456, 0.0413032, 0, 0, 0.270907, 0.189378, 
        0.203087, 0.126378, 0.0943184, 0.027322, 0.0349811, 0.0536282, 
        0, 0, 0.110408, 0.459793, 0.162302, 0.107188, 0.0667386, 
        0.0462276, 0.0122485, 0.0350946, 0, 0, 0.221055, 0.222473, 
        0.332989, 0.0911951, 0.0726362, 0.0278459, 0.0154733, 
        0.0163333, 0, 0, 0.192654, 0.325122, 0.172341, 0.19933, 
        0.0474159, 0.0436573, 0.0105977, 0.00888181, 0, 0, 0.0241952, 
        0.394852, 0.300496, 0.112572, 0.120485, 0.0260001, 0.0164109, 
        0.00498898, 0, 0, 0.0610734, 0.165811, 0.447244, 0.179443, 
        0.0888665, 0.0419339, 0.00995663, 0.0056706, 0, 0, 0.0688281, 
        0.272276, 0.131909, 0.329898, 0.135338, 0.0423926, 0.0137158, 
        0.00564149, 0, 0, 0.0366357, 0.24039, 0.273841, 0.127391, 
        0.228257, 0.0661179, 0.0187729, 0.00859439, 0, 0, 0.0170211, 
        0.10686, 0.314986, 0.186822, 0.102143, 0.212603, 0.0386068, 
        0.0209589, 0, 0, 0.0292021, 0.185009, 0.217455, 0.252027, 
        0.12456, 0.0681471, 0.102381, 0.0212193, 0, 0, 0.0398909, 
        0.122456, 0.272805, 0.212632, 0.1951, 0.0940702, 0.0230546, 
        0.0399919, 0, 0, 0.0729588, 0.341047, 0.209905, 0.165654, 
        0.087356, 0.0792927, 0.0289673, 0.0148187, 0, 0, 0.0636176, 
        0.241899, 0.3487, 0.179976, 0.0858252, 0.0413904, 0.0223061, 
        0.0162862, 0, 0, 0.175677, 0.173021, 0.226757, 0.26246, 
        0.0971319, 0.0377957, 0.0150723, 0.0120851, 0, 0, 0.0798062, 
        0.450678, 0.197245, 0.109728, 0.113848, 0.0301685, 0.0106123, 
        0.00791388, 0, 0, 0.0496263, 0.290698, 0.413208, 0.137967, 
        0.047305, 0.0434461, 0.009943, 0.00780655, 0, 0, 0.0214635, 
        0.230561, 0.412453, 0.259168, 0.0495184, 0.0157783, 0.00725885, 
        0.00379833, 0, 0, 0.0523269, 0.111374, 0.245841, 0.402822, 
        0.154104, 0.0232735, 0.00550857, 0.00474877, 0, 0, 0.0826881, 
        0.242931, 0.149745, 0.207967, 0.242032, 0.0615182, 0.00872894, 
        0.00438864, 0, 0, 0.131937, 0.234435, 0.286446, 0.123255, 
        0.108783, 0.0896789, 0.0216638, 0.00380142, 0, 0, 0.221507, 
        0.357415, 0.164185, 0.143504, 0.038715, 0.0300925, 0.0292497, 
        0.0153326, 0, 0, 0.0961764, 0.37693, 0.307046, 0.108792, 
        0.0685881, 0.0196256, 0.00935222, 0.0134897, 0, 0, 0.191263, 
        0.161659, 0.298863, 0.232037, 0.0730776, 0.0283431, 0.00555852, 
        0.00919908, 0, 0, 0.10153, 0.282183, 0.139746, 0.233295, 
        0.178739, 0.0408887, 0.0158664, 0.00775311, 0, 0, 0.0300199, 
        0.286636, 0.301559, 0.116994, 0.128639, 0.103867, 0.0199958, 
        0.0122904, 0, 0, 0.0492431, 0.10975, 0.361619, 0.287185, 
        0.0839184, 0.0549108, 0.0420233, 0.0113496, 0, 0, 0.0315137, 
        0.244047, 0.19003, 0.307299, 0.161824, 0.0348834, 0.0185587, 
        0.0118441, 0, 0, 0.137208, 0.0860543, 0.380255, 0.146806, 
        0.148938, 0.0734488, 0.0144361, 0.0128539, 0, 0, 0.146257, 
        0.323012, 0.120108, 0.251174, 0.0724961, 0.050684, 0.0260196, 
        0.0102478, 0, 0, 0.0855117, 0.266334, 0.350131, 0.0990576, 
        0.128873, 0.0320921, 0.0194974, 0.018503), Fit = c(0.000638965, 
        0.00539005, 0.0514821, 0.19173, 0.312928, 0.148901, 0.12184, 
        0.0799654, 0.036124, 0.0509998, 0.000409886, 0.0139091, 
        0.051432, 0.207722, 0.286914, 0.190819, 0.0846123, 0.0692351, 
        0.0454399, 0.0495077, 0.000714247, 0.00832158, 0.123764, 
        0.193218, 0.287313, 0.159426, 0.0986369, 0.0437373, 0.0357886, 
        0.04908, 0.0010244, 0.0130894, 0.0667764, 0.415362, 0.227884, 
        0.123364, 0.0628768, 0.0389019, 0.0172498, 0.0334719, 
        0.00031764, 0.0181587, 0.101581, 0.216404, 0.46935, 0.0920679, 
        0.0456671, 0.023276, 0.0144009, 0.0187765, 0.000511249, 
        0.00556349, 0.139304, 0.326849, 0.248225, 0.202328, 0.0366113, 
        0.0181598, 0.00925581, 0.0131932, 0.000466816, 0.00791425, 
        0.0377433, 0.398649, 0.342911, 0.103741, 0.0785823, 0.0142195, 
        0.00705309, 0.00871902, 0.000250395, 0.00824454, 0.0613179, 
        0.124613, 0.506018, 0.189427, 0.0538112, 0.0407611, 0.00737574, 
        0.00818112, 0.000262341, 0.00485798, 0.070216, 0.223974, 
        0.180101, 0.333972, 0.118009, 0.0335232, 0.0253933, 0.00969158, 
        0.000202924, 0.00481452, 0.03913, 0.24217, 0.303453, 
        0.110129, 0.192523, 0.0680279, 0.0193249, 0.0202252, 
        0.000385277, 0.00412606, 0.0429512, 0.14897, 0.356766, 
        0.196744, 0.0671295, 0.117353, 0.0414666, 0.0241079, 
        0.000313304, 0.00912447, 0.0428358, 0.188625, 0.243086, 
        0.238065, 0.122393, 0.0417606, 0.0730039, 0.0407933, 
        0.000322505, 0.00697885, 0.0890798, 0.176561, 0.286243, 
        0.148186, 0.135005, 0.0694081, 0.0236821, 0.0645338, 
        0.000936013, 0.00619379, 0.0587591, 0.317516, 0.234709, 
        0.15671, 0.0756961, 0.0689631, 0.035455, 0.0450626, 0.000878002, 
        0.0172103, 0.0499387, 0.201043, 0.409728, 0.127367, 0.0795414, 
        0.0384212, 0.0350037, 0.0408686, 0.000489238, 0.0170151, 
        0.146208, 0.179489, 0.268679, 0.224222, 0.0649908, 0.0405871, 
        0.019605, 0.038715, 0.000177721, 0.00790534, 0.120418, 
        0.43387, 0.189616, 0.106351, 0.0818394, 0.0237212, 0.014814, 
        0.0212865, 0.000243797, 0.00280508, 0.0546344, 0.348011, 
        0.440339, 0.0699475, 0.0360284, 0.0277246, 0.00803601, 
        0.0122298, 0.000194704, 0.00484183, 0.0244107, 0.200271, 
        0.464482, 0.2309, 0.0340273, 0.0175267, 0.0134872, 0.00985872, 
        0.000429596, 0.00456273, 0.0497497, 0.106331, 0.327478, 
        0.316651, 0.147086, 0.0216757, 0.0111647, 0.0148716, 
        0.000504525, 0.0106648, 0.0496371, 0.228163, 0.17826, 
        0.217427, 0.195237, 0.0906885, 0.0133646, 0.0160532, 
        0.000266852, 0.0113279, 0.104848, 0.20406, 0.32936, 0.0935051, 
        0.104733, 0.0940447, 0.0436842, 0.0141705, 0.000645264, 
        0.00519243, 0.0964787, 0.37206, 0.249576, 0.140106, 0.0363037, 
        0.0406631, 0.0365132, 0.0224624, 0.000773592, 0.0117176, 
        0.0412736, 0.31966, 0.425806, 0.0998716, 0.0512099, 0.0132693, 
        0.0148627, 0.0215562, 0.00028678, 0.0144853, 0.0961941, 
        0.143519, 0.415595, 0.22908, 0.0501615, 0.0257206, 0.00666464, 
        0.0182918, 0.000530789, 0.00498713, 0.110502, 0.312583, 
        0.178982, 0.224859, 0.116343, 0.0254754, 0.0130627, 0.0126746, 
        0.000130421, 0.00838321, 0.0345569, 0.326571, 0.356571, 
        0.0894646, 0.10562, 0.0546478, 0.0119662, 0.0120892, 
        0.000510948, 0.00241485, 0.0681118, 0.119952, 0.440896, 
        0.213702, 0.0504572, 0.0595685, 0.0308209, 0.013567, 
        0.000557106, 0.0109344, 0.022666, 0.271876, 0.182378, 
        0.286999, 0.130381, 0.0307844, 0.0363432, 0.0270815, 
        0.000652707, 0.0119655, 0.102941, 0.0901916, 0.400405, 
        0.109015, 0.159788, 0.0725902, 0.0171393, 0.035312, 0.000875772, 
        0.0126681, 0.101768, 0.36908, 0.118183, 0.207708, 0.0525131, 
        0.0769709, 0.0349672, 0.0252663, 0.000189883, 0.0140363, 
        0.0889552, 0.300633, 0.394533, 0.0490072, 0.0797777, 
        0.0201695, 0.0295635, 0.0231349)), .Names = c("Series", 
    "Year", "SS", "Sex", "Age", "Obs", "Fit"), row.names = c(NA, 
    -320L), class = "data.frame"), CAs = structure(list(Series = c(1L, 
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L), Year = c(1985L, 1985L, 
    1985L, 1985L, 1985L, 1985L, 1985L, 1985L, 1985L, 1985L, 1986L, 
    1986L, 1986L, 1986L, 1986L, 1986L, 1986L, 1986L, 1986L, 1986L, 
    1987L, 1987L, 1987L, 1987L, 1987L, 1987L, 1987L, 1987L, 1987L, 
    1987L, 1988L, 1988L, 1988L, 1988L, 1988L, 1988L, 1988L, 1988L, 
    1988L, 1988L, 1989L, 1989L, 1989L, 1989L, 1989L, 1989L, 1989L, 
    1989L, 1989L, 1989L, 1990L, 1990L, 1990L, 1990L, 1990L, 1990L, 
    1990L, 1990L, 1990L, 1990L, 1991L, 1991L, 1991L, 1991L, 1991L, 
    1991L, 1991L, 1991L, 1991L, 1991L, 1992L, 1992L, 1992L, 1992L, 
    1992L, 1992L, 1992L, 1992L, 1992L, 1992L, 1993L, 1993L, 1993L, 
    1993L, 1993L, 1993L, 1993L, 1993L, 1993L, 1993L, 1994L, 1994L, 
    1994L, 1994L, 1994L, 1994L, 1994L, 1994L, 1994L, 1994L, 1995L, 
    1995L, 1995L, 1995L, 1995L, 1995L, 1995L, 1995L, 1995L, 1995L, 
    1996L, 1996L, 1996L, 1996L, 1996L, 1996L, 1996L, 1996L, 1996L, 
    1996L, 1997L, 1997L, 1997L, 1997L, 1997L, 1997L, 1997L, 1997L, 
    1997L, 1997L, 1998L, 1998L, 1998L, 1998L, 1998L, 1998L, 1998L, 
    1998L, 1998L, 1998L, 1999L, 1999L, 1999L, 1999L, 1999L, 1999L, 
    1999L, 1999L, 1999L, 1999L, 2000L, 2000L, 2000L, 2000L, 2000L, 
    2000L, 2000L, 2000L, 2000L, 2000L, 2001L, 2001L, 2001L, 2001L, 
    2001L, 2001L, 2001L, 2001L, 2001L, 2001L, 2002L, 2002L, 2002L, 
    2002L, 2002L, 2002L, 2002L, 2002L, 2002L, 2002L, 2003L, 2003L, 
    2003L, 2003L, 2003L, 2003L, 2003L, 2003L, 2003L, 2003L), 
        SS = c(30, 30, 30, 30, 30, 30, 30, 30, 30, 30, 30, 30, 
        30, 30, 30, 30, 30, 30, 30, 30, 30, 30, 30, 30, 30, 30, 
        30, 30, 30, 30, 30, 30, 30, 30, 30, 30, 30, 30, 30, 30, 
        30, 30, 30, 30, 30, 30, 30, 30, 30, 30, 30, 30, 30, 30, 
        30, 30, 30, 30, 30, 30, 30, 30, 30, 30, 30, 30, 30, 30, 
        30, 30, 30, 30, 30, 30, 30, 30, 30, 30, 30, 30, 30, 30, 
        30, 30, 30, 30, 30, 30, 30, 30, 30, 30, 30, 30, 30, 30, 
        30, 30, 30, 30, 30, 30, 30, 30, 30, 30, 30, 30, 30, 30, 
        30, 30, 30, 30, 30, 30, 30, 30, 30, 30, 30, 30, 30, 30, 
        30, 30, 30, 30, 30, 30, 30, 30, 30, 30, 30, 30, 30, 30, 
        30, 30, 30, 30, 30, 30, 30, 30, 30, 30, 30, 30, 30, 30, 
        30, 30, 30, 30, 30, 30, 30, 30, 30, 30, 30, 30, 30, 30, 
        30, 30, 30, 30, 30, 30, 30, 30, 30, 30, 30, 30, 30, 30, 
        30, 30, 30, 30, 30, 30, 30, 30, 30, 30), Sex = c("Unisex", 
        "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
        "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
        "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
        "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
        "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
        "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
        "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
        "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
        "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
        "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
        "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
        "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
        "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
        "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
        "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
        "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
        "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
        "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
        "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
        "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
        "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
        "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
        "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
        "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
        "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
        "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
        "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
        "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
        "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
        "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
        "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
        "Unisex", "Unisex", "Unisex"), Age = c(1L, 2L, 3L, 4L, 
        5L, 6L, 7L, 8L, 9L, 10L, 1L, 2L, 3L, 4L, 5L, 6L, 7L, 
        8L, 9L, 10L, 1L, 2L, 3L, 4L, 5L, 6L, 7L, 8L, 9L, 10L, 
        1L, 2L, 3L, 4L, 5L, 6L, 7L, 8L, 9L, 10L, 1L, 2L, 3L, 
        4L, 5L, 6L, 7L, 8L, 9L, 10L, 1L, 2L, 3L, 4L, 5L, 6L, 
        7L, 8L, 9L, 10L, 1L, 2L, 3L, 4L, 5L, 6L, 7L, 8L, 9L, 
        10L, 1L, 2L, 3L, 4L, 5L, 6L, 7L, 8L, 9L, 10L, 1L, 2L, 
        3L, 4L, 5L, 6L, 7L, 8L, 9L, 10L, 1L, 2L, 3L, 4L, 5L, 
        6L, 7L, 8L, 9L, 10L, 1L, 2L, 3L, 4L, 5L, 6L, 7L, 8L, 
        9L, 10L, 1L, 2L, 3L, 4L, 5L, 6L, 7L, 8L, 9L, 10L, 1L, 
        2L, 3L, 4L, 5L, 6L, 7L, 8L, 9L, 10L, 1L, 2L, 3L, 4L, 
        5L, 6L, 7L, 8L, 9L, 10L, 1L, 2L, 3L, 4L, 5L, 6L, 7L, 
        8L, 9L, 10L, 1L, 2L, 3L, 4L, 5L, 6L, 7L, 8L, 9L, 10L, 
        1L, 2L, 3L, 4L, 5L, 6L, 7L, 8L, 9L, 10L, 1L, 2L, 3L, 
        4L, 5L, 6L, 7L, 8L, 9L, 10L, 1L, 2L, 3L, 4L, 5L, 6L, 
        7L, 8L, 9L, 10L), Obs = c(0.0512773, 0.344339, 0.108042, 
        0.149089, 0.199343, 0.0699715, 0.0460689, 0.015036, 0.00995164, 
        0.00688244, 0.0597677, 0.240022, 0.37874, 0.0888986, 
        0.0841425, 0.104475, 0.0263168, 0.00982918, 0.0032896, 
        0.00451825, 0.0136367, 0.107823, 0.38519, 0.306471, 0.0787566, 
        0.0456549, 0.0449077, 0.00960173, 0.00336248, 0.00459538, 
        0.0126568, 0.0270797, 0.26377, 0.373855, 0.245594, 0.0287354, 
        0.0216344, 0.022591, 0.002134, 0.00195003, 0.017625, 
        0.0717651, 0.0958468, 0.338976, 0.29487, 0.149202, 0.018323, 
        0.0063258, 0.00497339, 0.00209406, 0.0415639, 0.0881364, 
        0.195485, 0.105181, 0.201615, 0.242057, 0.106302, 0.011288, 
        0.00396202, 0.00441056, 0.030792, 0.126832, 0.139772, 
        0.235189, 0.118803, 0.14102, 0.163159, 0.0329747, 0.00623636, 
        0.00522295, 0.00684215, 0.162786, 0.31607, 0.179321, 
        0.154614, 0.0621496, 0.0541671, 0.0485603, 0.0122589, 
        0.00323102, 0.0342315, 0.0462173, 0.294947, 0.349123, 
        0.126954, 0.0952153, 0.0204238, 0.0167801, 0.0112187, 
        0.00489021, 0.14657, 0.152992, 0.091428, 0.271736, 0.223219, 
        0.0588115, 0.0368974, 0.00713485, 0.00489247, 0.00631944, 
        0.0105395, 0.259289, 0.221329, 0.0802965, 0.21329, 0.158003, 
        0.0337621, 0.0157199, 0.00312612, 0.00464452, 0.0290375, 
        0.0427757, 0.332527, 0.229803, 0.100226, 0.114121, 0.109203, 
        0.0297401, 0.00819608, 0.00437124, 0.00815309, 0.150866, 
        0.0914359, 0.378546, 0.195742, 0.0638771, 0.0586888, 
        0.044404, 0.00377333, 0.00451452, 0.048751, 0.0336297, 
        0.181334, 0.0971391, 0.373616, 0.171354, 0.0393758, 0.0314522, 
        0.018448, 0.00489929, 0.0520459, 0.23227, 0.0493697, 
        0.297697, 0.0916966, 0.166631, 0.0783154, 0.0165505, 
        0.00929643, 0.00612719, 0.117496, 0.174462, 0.342296, 
        0.0433967, 0.187594, 0.0517759, 0.0511506, 0.0258879, 
        0.00318909, 0.00275138, 0.0901008, 0.160937, 0.272525, 
        0.278601, 0.0363812, 0.112922, 0.024674, 0.0145969, 0.00585359, 
        0.00340842, 0.00527583, 0.218316, 0.235807, 0.230302, 
        0.207363, 0.0407157, 0.0477692, 0.00854456, 0.00412891, 
        0.00177773, 0.0691984, 0.0275059, 0.287201, 0.238818, 
        0.195205, 0.118263, 0.0254615, 0.0291785, 0.00669062, 
        0.00247801), Fit = c(0.0835561, 0.229767, 0.142831, 0.188116, 
        0.203169, 0.0604952, 0.0377795, 0.0182488, 0.0166256, 
        0.0194112, 0.0395434, 0.192933, 0.355162, 0.142642, 0.113153, 
        0.0904507, 0.0262172, 0.0163727, 0.00790859, 0.0156175, 
        0.015593, 0.0973032, 0.317529, 0.374286, 0.0866851, 0.0465706, 
        0.035837, 0.0103874, 0.00648697, 0.00932123, 0.0278185, 
        0.0449021, 0.187358, 0.390438, 0.261801, 0.0398343, 0.0205177, 
        0.0157888, 0.00457641, 0.00696471, 0.0258808, 0.0902879, 
        0.0975178, 0.261743, 0.3217, 0.153182, 0.0225741, 0.0116274, 
        0.00894752, 0.00654037, 0.0545917, 0.0813407, 0.190002, 
        0.132855, 0.216834, 0.200829, 0.0932861, 0.0137474, 0.00708096, 
        0.00943199, 0.0541123, 0.160467, 0.160001, 0.24061, 0.0996202, 
        0.116388, 0.10451, 0.0485452, 0.00715401, 0.00859322, 
        0.02547, 0.151679, 0.30076, 0.191501, 0.163798, 0.0445425, 
        0.0498912, 0.0447994, 0.0208095, 0.00675029, 0.0608188, 
        0.0686576, 0.273297, 0.3448, 0.12257, 0.0659078, 0.0170778, 
        0.0191285, 0.0171763, 0.0105666, 0.077193, 0.164029, 
        0.123777, 0.313623, 0.22139, 0.049738, 0.0255035, 0.00660837, 
        0.00740193, 0.0107354, 0.0274876, 0.194775, 0.277101, 
        0.135255, 0.207557, 0.109586, 0.0239959, 0.0123041, 0.00318819, 
        0.00875031, 0.0504747, 0.0665303, 0.315808, 0.292262, 
        0.088683, 0.106719, 0.0552168, 0.0120908, 0.00619962, 
        0.00601543, 0.0148537, 0.133942, 0.118284, 0.365696, 
        0.211599, 0.0508534, 0.0600361, 0.0310628, 0.00680178, 
        0.00687172, 0.0622297, 0.04126, 0.249313, 0.143642, 0.279793, 
        0.1299, 0.0306708, 0.0362091, 0.0187347, 0.00824681, 
        0.0622535, 0.17141, 0.0761208, 0.298711, 0.106188, 0.160061, 
        0.0727143, 0.0171686, 0.0202688, 0.0151035, 0.0629793, 
        0.161967, 0.298517, 0.0855658, 0.201307, 0.0524982, 0.0769491, 
        0.0349572, 0.00825378, 0.0170052, 0.0733498, 0.148845, 
        0.256165, 0.303936, 0.0515754, 0.0868244, 0.0219511, 
        0.0321747, 0.0146167, 0.0105616, 0.0174999, 0.181477, 
        0.24639, 0.272421, 0.189458, 0.0225419, 0.0366954, 0.00927738, 
        0.0135983, 0.0106413, 0.0588922, 0.0441024, 0.306234, 
        0.269207, 0.18112, 0.0950447, 0.0110333, 0.0179608, 0.00454088, 
        0.0118643)), .Names = c("Series", "Year", "SS", "Sex", 
    "Age", "Obs", "Fit"), row.names = c(NA, -190L), class = "data.frame")), .Names = c("N", 
"B", "Sel", "Dev", "Survey", "CAc", "CAs"), call = quote(importCol(res.file = "c:/scape/example/cod.res", 
    Dev = T, Survey = T, CAc = T, CAs = T)), scape.version = "1.1-5", info = "", class = "scape")
